@@ -14,17 +14,42 @@ my $in_file = 'originas';
 
 my $temp = "$in_file.inet";
 parse_raw_file($in_file, $temp);
-system(qq[sort -t, -k1 -n $temp | uniq > $temp.sort]);
-system(qq[refine_inet.pl $temp.sort $dst]);
+system(qq[sort -t, -k1,1 -n $temp | uniq > $temp.sort]);
+system(qq[refine_inet.pl $temp.sort $dst.clean]);
 
-unlink($temp);
-unlink("$temp.sort");
+fix_gap_as("$dst.clean", $dst);
+
+#unlink($temp);
+#unlink("$temp.sort");
+
+sub fix_gap_as {
+    my ( $raw, $dst ) = @_;
+    open my $fh,  '<', $raw;
+    open my $fhw, '>', $dst;
+    my $head=<$fh>;
+    chomp($head);
+    my ($s, $e, $d) = split /,/, $head;
+    while (<$fh>) {
+        chomp;
+        my ($ss, $ee, $dd) = split /,/;
+        if($dd ne $d){
+            print $fhw join(",", $s, $e, $d),"\n";
+            ($s, $e, $d) = ($ss, $ee, $dd);
+        }else{
+            ($s, $e, $d) = ($s, $ee, $d);
+        }
+    }
+    print $fhw join(",", $s, $e, $d),"\n";
+    close $fhw;
+    close $fh;
+    return $dst;
+}
 
 sub parse_raw_file {
     my ( $raw, $temp ) = @_;
     open my $fh,  '<', $raw;
     open my $fhw, '>', $temp;
-    print $fhw "-1,-1,-1\n";
+    print $fhw "s,e,as\n";
     while (<$fh>) {
         my $rr = extract_asn_line($_);
         print $fhw join(",", @$rr),"\n";
